/*
 * Copyright (c) 2007 Kathryn Huxtable
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ErrorPage.java 1000 2007-04-03 17:33:26Z huxtable $
 */
package org.kathrynhuxtable.middleware.shibshim.filter;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletResponse;

import org.apache.log4j.Logger;

/**
 * Error page for the Shibboleth shim filter. Since we can't put JSP files in a
 * jar and have them dispatched to, we have to code a simple error page.
 */
public class ErrorPage {
    /**
     * Logger for error/information/debug messages.
     */
    private static Logger log = Logger.getLogger(ErrorPage.class.getName());

    /**
     * Print an error page and throw ImmediateReturnException.
     * 
     * @param response
     *            the response object.
     * @param errorText
     *            the error message to print.
     * @throws ImmediateReturnException
     *             because we have printed an error page.
     */
    public static void displayErrorPage(ServletResponse response, String errorText) throws ImmediateReturnException {
        try {
            PrintWriter out = response.getWriter();
            response.setContentType("text/html");

            out.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            out.println("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">");
            out.println("<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\">");
            out.println(" <head>");
            out.println("  <title>Shibboleth Shim Authentication Error</title>");
            out.println(" </head>");
            out.println(" <body>");
            out.println("  <h1>Shibboleth Shim Authentication Error</h1>");
            out.println("   <p>");
            out.println("    <strong>An error has occurred:</strong>");
            out.println("   </p>");
            out.println("   <p>");
            out.println(errorText);
            out.println("   </p>");
            out.println(" </body>");
            out.println("</html>");
            out.close();
        } catch (IOException e) {
            log.fatal("Unable to obtain PrintWriter to print error page" + e);
        }
        throw new ImmediateReturnException();
    }
}
