/*
 Copyright (c) 2007 Kathryn Huxtable

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 $Id: ErrorPageTest.java 1248 2007-04-18 12:00:08Z kathryn5 $
 */
package org.kathrynhuxtable.middleware.shibshim.filter;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.http.HttpServletResponse;

import junit.framework.TestCase;

import org.easymock.MockControl;

/**
 * Test the ErrorPage class.
 */
public class ErrorPageTest extends TestCase {
    
    private String errorText = "This is an error";
    
    private String page =
        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
        + "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n"
        + "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\">\n"
        + " <head>\n"
        + "  <title>Shibboleth Shim Authentication Error</title>\n"
        + " </head>\n"
        + " <body>\n"
        + "  <h1>Shibboleth Shim Authentication Error</h1>\n"
        + "   <p>\n"
        + "    <strong>An error has occurred:</strong>\n"
        + "   </p>\n"
        + "   <p>\n"
        + errorText + "\n"
        + "   </p>\n"
        + " </body>\n"
        + "</html>\n";

    private MockControl         controlResponse;
    private HttpServletResponse response;

    public void setUp() {
        controlResponse = MockControl.createControl(HttpServletResponse.class);
        response = (HttpServletResponse) controlResponse.getMock();
    }

    public void tearDown() {
        controlResponse.verify();
    }

    public void testSuccess() {
        ByteArrayOutputStream stream = new ByteArrayOutputStream();
        PrintWriter out = new PrintWriter(stream);
        try {
            response.getWriter();
        } catch (IOException e) {
            // Can't happen. This is a mock response object.
            fail("Got IOException calling mock response.getWriter: " + e);
        }
        controlResponse.setReturnValue(out);
        response.setContentType("text/html");

        controlResponse.replay();

        try {
            ErrorPage.displayErrorPage(response, errorText);
        } catch (ImmediateReturnException e) {
            assertEquals(page, stream.toString());
            return;
        }
        fail("Failed to catch ImmediateReturnException");
    }
}
